CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
61 lines
2.1 KiB
C++
61 lines
2.1 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include "vulkan_test.hh"
|
|
#include "signal_semaphore_common.hh"
|
|
|
|
HIP_TEST_CASE(Unit_hipSignalExternalSemaphoresAsync_Vulkan_Positive_Binary_Semaphore) {
|
|
SignalExternalSemaphoreCommon(hipSignalExternalSemaphoresAsync);
|
|
}
|
|
|
|
// Timeline semaphores unsupported on AMD
|
|
#if HT_NVIDIA
|
|
HIP_TEST_CASE(Unit_hipSignalExternalSemaphoresAsync_Vulkan_Positive_Timeline_Semaphore) {
|
|
SignalExternalTimelineSemaphoreCommon(hipSignalExternalSemaphoresAsync);
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipSignalExternalSemaphoresAsync_Vulkan_Positive_Multiple_Semaphores) {
|
|
SignalExternalMultipleSemaphoresCommon(hipSignalExternalSemaphoresAsync);
|
|
}
|
|
#endif
|
|
|
|
HIP_TEST_CASE(Unit_hipSignalExternalSemaphoresAsync_Vulkan_Negative_Parameters) {
|
|
VulkanTest vkt(enable_validation);
|
|
hipExternalSemaphoreSignalParams signal_params = {};
|
|
signal_params.params.fence.value = 1;
|
|
|
|
SECTION("extSemArray == nullptr") {
|
|
HIP_CHECK_ERROR(hipSignalExternalSemaphoresAsync(nullptr, &signal_params, 1, nullptr),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("paramsArray == nullptr") {
|
|
const auto hip_ext_semaphore = ImportBinarySemaphore(vkt);
|
|
HIP_CHECK_ERROR(hipSignalExternalSemaphoresAsync(&hip_ext_semaphore, nullptr, 1, nullptr),
|
|
hipErrorInvalidValue);
|
|
HIP_CHECK(hipDestroyExternalSemaphore(hip_ext_semaphore));
|
|
}
|
|
|
|
SECTION("Wait params flags != 0") {
|
|
const auto hip_ext_semaphore = ImportBinarySemaphore(vkt);
|
|
signal_params.flags = 1;
|
|
HIP_CHECK_ERROR(
|
|
hipSignalExternalSemaphoresAsync(&hip_ext_semaphore, &signal_params, 1, nullptr),
|
|
hipErrorInvalidValue);
|
|
HIP_CHECK(hipDestroyExternalSemaphore(hip_ext_semaphore));
|
|
}
|
|
|
|
SECTION("Invalid stream") {
|
|
const auto hip_ext_semaphore = ImportBinarySemaphore(vkt);
|
|
hipStream_t stream = nullptr;
|
|
HIP_CHECK(hipStreamCreate(&stream));
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
HIP_CHECK_ERROR(hipSignalExternalSemaphoresAsync(&hip_ext_semaphore, &signal_params, 1, stream),
|
|
hipErrorInvalidValue);
|
|
HIP_CHECK(hipDestroyExternalSemaphore(hip_ext_semaphore));
|
|
}
|
|
}
|